==> taler-wallet-v0.11.2.tar.gz: taler-wallet-v0.11.2/packages/taler-harness/src/integrationtests/test-wallet-refresh-errors.ts <==
/*
 This file is part of GNU Taler
 (C) 2020 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 * Imports.
 */
import { AmountString } from "@gnu-taler/taler-util";
import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
import { CoinConfig } from "../harness/denomStructures.js";
import { GlobalTestState } from "../harness/harness.js";
import {
  createSimpleTestkudosEnvironmentV2,
  withdrawViaBankV2,
} from "../harness/helpers.js";

const coinCommon = {
  cipher: "RSA" as const,
  durationLegal: "3 years",
  durationSpend: "2 years",
  durationWithdraw: "7 days",
  feeDeposit: "TESTKUDOS:0",
  feeRefresh: "TESTKUDOS:0",
  feeRefund: "TESTKUDOS:0",
  feeWithdraw: "TESTKUDOS:0",
  rsaKeySize: 1024,
};

/**
 * Run test for refreshe after a payment.
 */
export async function runWalletRefreshErrorsTest(t: GlobalTestState) {
  // Set up test environment

  const coinConfigList: CoinConfig[] = [
    {
      ...coinCommon,
      name: "n1",
      value: "TESTKUDOS:1",
    },
    {
      ...coinCommon,
      name: "n5",
      value: "TESTKUDOS:5",
    },
  ];

  const { walletClient, bank, exchange, merchant } =
    await createSimpleTestkudosEnvironmentV2(t, coinConfigList);

  const wres = await withdrawViaBankV2(t, {
    amount: "TESTKUDOS:5",
    bank,
    exchange,
    walletClient,
  });
  await wres.withdrawalFinishedCond;

  const backupResp = await walletClient.call(
    WalletApiOperation.CreateStoredBackup,
    {},
  );

  const coinDump = await walletClient.call(WalletApiOperation.DumpCoins, {});

  t.assertDeepEqual(coinDump.coins.length, 1);

  await walletClient.call(WalletApiOperation.ForceRefresh, {
    refreshCoinSpecs: [
      {
        coinPub: coinDump.coins[0].coin_pub,
        amount: "TESTKUDOS:3" as AmountString,
      },
    ],
  });

  await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});

  await walletClient.call(WalletApiOperation.RecoverStoredBackup, {
    name: backupResp.name,
  });

  await walletClient.call(WalletApiOperation.ForceRefresh, {
    refreshCoinSpecs: [
      {
        coinPub: coinDump.coins[0].coin_pub,
        amount: "TESTKUDOS:3" as AmountString,
      },
    ],
  });

  await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});
}

runWalletRefreshErrorsTest.suites = ["wallet"];

==> taler-wallet-v0.12.7.tar.gz: taler-wallet-v0.12.7/packages/taler-harness/src/integrationtests/test-wallet-refresh-errors.ts <==
/*
 This file is part of GNU Taler
 (C) 2020 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 * Imports.
 */
import { AmountString } from "@gnu-taler/taler-util";
import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
import { CoinConfig } from "../harness/denomStructures.js";
import { GlobalTestState } from "../harness/harness.js";
import {
  createSimpleTestkudosEnvironmentV2,
  withdrawViaBankV2,
} from "../harness/helpers.js";

const coinCommon = {
  cipher: "RSA" as const,
  durationLegal: "3 years",
  durationSpend: "2 years",
  durationWithdraw: "7 days",
  feeDeposit: "TESTKUDOS:0",
  feeRefresh: "TESTKUDOS:0",
  feeRefund: "TESTKUDOS:0",
  feeWithdraw: "TESTKUDOS:0",
  rsaKeySize: 1024,
};

/**
 * Run test for refreshe after a payment.
 */
export async function runWalletRefreshErrorsTest(t: GlobalTestState) {
  // Set up test environment

  const coinConfigList: CoinConfig[] = [
    {
      ...coinCommon,
      name: "n1",
      value: "TESTKUDOS:1",
    },
    {
      ...coinCommon,
      name: "n5",
      value: "TESTKUDOS:5",
    },
  ];

  const { walletClient, bank, exchange, merchant } =
    await createSimpleTestkudosEnvironmentV2(t, coinConfigList);

  const wres = await withdrawViaBankV2(t, {
    amount: "TESTKUDOS:5",
    bank,
    exchange,
    walletClient,
  });
  await wres.withdrawalFinishedCond;

  const backupResp = await walletClient.call(
    WalletApiOperation.CreateStoredBackup,
    {},
  );

  const coinDump = await walletClient.call(WalletApiOperation.DumpCoins, {});

  t.assertDeepEqual(coinDump.coins.length, 1);

  await walletClient.call(WalletApiOperation.ForceRefresh, {
    refreshCoinSpecs: [
      {
        coinPub: coinDump.coins[0].coinPub,
        amount: "TESTKUDOS:3" as AmountString,
      },
    ],
  });

  await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});

  await walletClient.call(WalletApiOperation.RecoverStoredBackup, {
    name: backupResp.name,
  });

  await walletClient.call(WalletApiOperation.ForceRefresh, {
    refreshCoinSpecs: [
      {
        coinPub: coinDump.coins[0].coinPub,
        amount: "TESTKUDOS:3" as AmountString,
      },
    ],
  });

  await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});
}

runWalletRefreshErrorsTest.suites = ["wallet"];
